AppConfig class

Constructors

AppConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

appId ↔ String?
getter/setter pair
appVersion → String?
no setter
baseUrl ↔ String
latefinal
baseWebUrl ↔ String
latefinal
buildNumber → String?
no setter
deviceManufacturer → String?
no setter
deviceModel → String?
no setter
enablePrintLog → bool
no setter
endpoint → String?
no setter
isRelease → bool
no setter
osVersion → String?
no setter
osVersionSdk → int?
no setter
platform → String
no setter

Static Methods

init() → Future
log() → void
setFlavorConfig({required String baseUrl, required String baseWebUrl, bool isRelease = false, String? endpoint, bool enablePrintLog = false}) → dynamic
baseUrl, baseWebUrl, endpoint flavor, logging user set this config in main()